@@ -1,5 +1,5 @@
 from __future__ import print_function
-from transcriptic.config import Connection
+from .config import Connection
 from .version import __version__
 
 api = None
@@ -21,6 +21,15 @@ The __init__ file contains a bunch of entry functions to facilitate easy access
 to the Jupyter library.
 """
 
+""" Allow direct import of Jupyter objects such as `Run` directly if the
+required imports are present
+"""
+try:
+    from .jupyter import Run, Project, Container, Dataset
+    from .commands import ProtocolPreview
+except ImportError as e:
+    pass
+
 
 def run(run_id):
     """
@@ -86,8 +95,8 @@ def preview(protocol):
     Protocol object: ProtocolPreview
         Transcriptic representation of a Protocol object
     """
-    from .cli import ProtocolPreview
-    return ProtocolPreview(protocol, connection=api)
+    from .commands import ProtocolPreview
+    return ProtocolPreview(protocol, api=api)
 
 
 def analyze(protocol, test_mode=False):
